from django.test import TestCase

from ..exceptions import InvalidExpiredToken


class TestInvalidExpiredToken(TestCase):
    """Assert `InvalidExpiredToken` behaves as expected."""
    def test_raise(self):
        """Assert `InvalidExpiredToken` can be raised."""
        with self.assertRaises(InvalidExpiredToken) as error:
            raise InvalidExpiredToken

        self.assertEqual(error.exception.message, 'Invalid or expired token.')



from incuna_test_utils.testcases.urls import URLTestCase

from .. import views


class TestURLs(URLTestCase):
    def test_password_reset_confirm_url(self):
        self.assert_url_matches_view(
            view=views.VerifyUserEmailView,
            expected_url='/register/verify/x:-y/',
            url_name='user_management_api:registration-verify',
            url_kwargs={'token': 'x:-y'},
        )



from django.conf.urls import url

from . import views


urlpatterns = [
    url(
        r'^register/verify/(?P<token>[0-9A-Za-z:\-_]+)/$',
        views.VerifyUserEmailView.as_view(),
        name='registration-verify',
    ),
]
